% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/coerce.R
\name{SpatialFeatureExperiment-coercion}
\alias{SpatialFeatureExperiment-coercion}
\alias{toSpatialFeatureExperiment}
\alias{toSpatialFeatureExperiment,SpatialExperiment-method}
\title{SpatialFeatureExperiment coercion methods}
\usage{
\S4method{toSpatialFeatureExperiment}{SpatialExperiment}(
  x,
  colGeometries = NULL,
  rowGeometries = NULL,
  annotGeometries = NULL,
  spatialCoordsNames = c("x", "y"),
  annotGeometryType = "POLYGON",
  spatialGraphs = NULL,
  spotDiameter = NA,
  unit = NULL,
  BPPARAM = SerialParam()
)
}
\arguments{
\item{x}{A \code{SpatialExperiment} object to be coerced to a
\code{SpatialFeatureExperiment} object.}

\item{colGeometries}{Geometry of the entities that correspond to the columns
of the gene count matrix, such as cells and Visium spots. It must be a
named list of one of the following: \describe{ \item{An \code{sf} data
frame}{The geometry column specifies the geometry of the entities.}
\item{An ordinary data frame specifying centroids}{Column names for the
coordinates are specified in the \code{spatialCoordsNames} argument. For
Visium and ST, in addition to the centroid coordinate data frame, the spot
diameter in the same unit as the coordinates can be specified in the
\code{spotDiamter} argument.} \item{An ordinary data frame specifying
polygons}{Also use \code{spatialCoordsNames}. There should an additional
column "ID" to specify which vertices belong to which polygon. The
coordinates should not be in list columns. Rather, the data frame should
look like it is passed to \code{ggplot2::geom_polygon}. If there are holes,
then there must also be a column "subID" that differentiates between the
outer polygon and the holes.}} In all cases, the data frame should specify
the same number of geometries as the number of columns in the gene count
matrix. If the column "barcode" is present, then it will be matched to
column names of the gene count matrix. Otherwise, the geometries are
assumed to be in the same order as columns in the gene count matrix. If the
geometries are specified in an ordinary data frame, then it will be
converted into \code{sf} internally. Named list of data frames because each
entity can have multiple geometries, such as whole cell and nuclei
segmentations. The geometries are assumed to be POINTs for centroids and
POLYGONs for segmentations. If polygons are specified in an ordinary data
frame, then anything with fewer than 3 vertices will be removed. For
anything other than POINTs, attributes of the geometry will be ignored.}

\item{rowGeometries}{Geometry associated with genes or features, which
correspond to rows of the gene count matrix.}

\item{annotGeometries}{Geometry of entities that do not correspond to columns
or rows of the gene count matrix, such as tissue boundary and pathologist
annotations of histological regions, and nuclei segmentation in a Visium
dataset. Also a named list as in \code{colGeometries}. The ordinary data
frame may specify POINTs, POLYGONs, or LINESTRINGs, or their MULTI
versions. Each data frame can only specify one type of geometry. For MULTI
versions, there must be a column "group" to identify each MULTI geometry.}

\item{spatialCoordsNames}{A \code{character} vector of column names if
\code{*Geometries} arguments have ordinary data frames, to identify the
columns in the ordinary data frames that specify the spatial coordinates.
If \code{colGeometries} is not specified, then this argument will behave as
in \code{\link{SpatialExperiment}}, but \code{colGeometries} will be given
precedence if provided.}

\item{annotGeometryType}{Character vector specifying geometry type of each
element of the list if \code{annotGeometry} is specified. Each element of
the vector must be one of POINT, LINESTRING, POLYGON, MULTIPOINT,
MULTILINESTRING, and MULTIPOLYGON. Must be either length 1 (same for all
elements of the list) or the same length as the list. Ignored if the
corresponding element is an \code{sf} object.}

\item{spatialGraphs}{A named list of \code{listw} objects (see \code{spdep})
for spatial neighborhood graphs.}

\item{spotDiameter}{Spot diameter for technologies with arrays of spots of
fixed diameter per slide, such as Visium, ST, DBiT-seq, and slide-seq. The
diameter must be in the same unit as the coordinates in the *Geometry
arguments. Ignored for geometries that are not POINT or MULTIPOINT.}

\item{unit}{Unit the coordinates are in. I'm thinking about using some custom
engineering CRS's which can convert units and invert the y axis for
Cartesian vs. image orientations. Units are also helpful when plotting
scale bars. Ignored for now, until I find a better way to deal with it.}

\item{BPPARAM}{Passed to \code{\link{df2sf}}, to parallelize the conversion
of centroid spatial coordinates in the SPE object to \code{sf} point
geometry.}
}
\value{
An SFE object
}
\description{
The \code{SpatialFeatureExperiment} class inherits from
\code{SpatialExperiment}, which in turn inherits from
\code{SingleCellExperiment}. A \code{SpatialExperiment} object with
geometries in \code{colGeometries} in the \code{int_colData},
\code{rowGeometries} in the \code{int_elementMetadata}, or
\code{annotGeometries} in the \code{int_metadata} can be directly converted
to \code{SpatialFeatureExperiment} with \code{as(spe,
"SpatialFeatureExperiment")}. A \code{SpatialExperiment} object without the
geometries can also be converted; the coordinates in the \code{spatialCoords}
field will be used to make POINT geometries named "centroids" to add to
\code{colGeometries}. The geometries can also be supplied separately when
using \code{toSpatialFeatureExperiment}. For now coercion only works for
\code{SpatialExperiment}. I'll deal with \code{Seurat} and
\code{SingleCellExperiment} later.
}
\examples{
library(SpatialExperiment)
example(read10xVisium)
# There can't be suplicate barcodes
colnames(spe) <- make.unique(colnames(spe), sep = "-")
rownames(spatialCoords(spe)) <- colnames(spe)
sfe <- toSpatialFeatureExperiment(spe)
}
